@@ -874,13 +874,16 @@ remove_option(struct rush_request *req, struct option_defn *opt)
 					   option cluster. */
 					continue;
 				}
+				/* Advance to the character following the
+				   option name */
+				p++;
 			} else {
 				/* Skip unrecognized short option */
 				continue;
 			}
 
 			/* Remove the option (and its parameter, if any) */
-			if (remove_optarg(req, opt, i, p + 1)) {
+			if (remove_optarg(req, opt, i, p)) {
 				i--;
 				mod = 1;
 			}
@@ -1183,7 +1186,7 @@ setowner(struct rush_request *req)
 {
 	size_t gidc;
 	gid_t *gidv;
-	
+
 	get_user_groups(req, &gidc, &gidv);
 	if (setgroups(gidc, gidv) < 0)
 		die(system_error, &req->i18n,
